
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_BOOK_CONTACTS_ENUMTYPES_H
#define E_BOOK_CONTACTS_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-book-contacts-enums.h" */
#define E_TYPE_BOOK_CLIENT_VIEW_FLAGS	(e_book_client_view_flags_get_type())
GType e_book_client_view_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_BOOK_INDEX_TYPE	(e_book_index_type_get_type())
GType e_book_index_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_BOOK_CURSOR_SORT_TYPE	(e_book_cursor_sort_type_get_type())
GType e_book_cursor_sort_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_BOOK_CURSOR_ORIGIN	(e_book_cursor_origin_get_type())
GType e_book_cursor_origin_get_type	(void) G_GNUC_CONST;
#define E_TYPE_BOOK_CURSOR_STEP_FLAGS	(e_book_cursor_step_flags_get_type())
GType e_book_cursor_step_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_BOOK_OPERATION_FLAGS	(e_book_operation_flags_get_type())
GType e_book_operation_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_VCARD_VERSION	(e_vcard_version_get_type())
GType e_vcard_version_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTACT_DATE_TIME_FLAGS	(e_contact_date_time_flags_get_type())
GType e_contact_date_time_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_VCARD_FOREACH_FLAGS	(e_vcard_foreach_flags_get_type())
GType e_vcard_foreach_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_BOOK_CONTACTS_ENUMTYPES_H */

/* Generated data ends here */

